nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Cfg2

Struct Cfg2 

#[repr(transparent)]
pub struct Cfg2(pub u32);
Configuration register 2 for the primary channel pair.

Tuple Fields

0: u32

Implementations

Source

impl Cfg2

pub const fn framelen(&self) -> u16

Frame Length, minus 1 encoded, defines the number of clocks and data bits in the frames that this channel pair participates in.

pub const fn set_framelen(&mut self, val: u16)

Frame Length, minus 1 encoded, defines the number of clocks and data bits in the frames that this channel pair participates in.

pub const fn position(&self) -> u16

Data Position.

pub const fn set_position(&mut self, val: u16)

Data Position.