#[repr(transparent)]pub struct Fifointenset(pub u32);Expand description
FIFO interrupt enable set (enable) and read register.
Tuple Fields
0: u32Implementations
Sourceimpl Fifointenset
impl Fifointenset
Sourcepub const fn txerr(&self) -> bool
pub const fn txerr(&self) -> bool
Determines whether an interrupt occurs when a transmit error occurs, based on the TXERR flag in the FIFOSTAT register.
Sourcepub const fn set_txerr(&mut self, val: bool)
pub const fn set_txerr(&mut self, val: bool)
Determines whether an interrupt occurs when a transmit error occurs, based on the TXERR flag in the FIFOSTAT register.
Sourcepub const fn rxerr(&self) -> bool
pub const fn rxerr(&self) -> bool
Determines whether an interrupt occurs when a receive error occurs, based on the RXERR flag in the FIFOSTAT register.
Sourcepub const fn set_rxerr(&mut self, val: bool)
pub const fn set_rxerr(&mut self, val: bool)
Determines whether an interrupt occurs when a receive error occurs, based on the RXERR flag in the FIFOSTAT register.
Sourcepub const fn txlvl(&self) -> bool
pub const fn txlvl(&self) -> bool
Determines whether an interrupt occurs when a the transmit FIFO reaches the level specified by the TXLVL field in the FIFOTRIG register.
Sourcepub const fn set_txlvl(&mut self, val: bool)
pub const fn set_txlvl(&mut self, val: bool)
Determines whether an interrupt occurs when a the transmit FIFO reaches the level specified by the TXLVL field in the FIFOTRIG register.