#[repr(transparent)]pub struct Cfg2(pub u32);Expand description
Configuration register 2 for the primary channel pair.
Tuple Fields
0: u32Implementations
Sourceimpl Cfg2
impl Cfg2
Sourcepub const fn framelen(&self) -> u16
pub const fn framelen(&self) -> u16
Frame Length, minus 1 encoded, defines the number of clocks and data bits in the frames that this channel pair participates in.
Sourcepub const fn set_framelen(&mut self, val: u16)
pub const fn set_framelen(&mut self, val: u16)
Frame Length, minus 1 encoded, defines the number of clocks and data bits in the frames that this channel pair participates in.
Sourcepub const fn set_position(&mut self, val: u16)
pub const fn set_position(&mut self, val: u16)
Data Position.